@@ -45,7 +45,7 @@ from . import vaswani
 from . import wapo
 from . import wikiclir
 from . import wikir
-from . import trec_fair_2021
+from . import trec_fair
 from . import trec_cast # must be after wapo,car,msmarco_passage
 from . import hc4
 from . import neuclir # must be after hc4
\ No newline at end of file
